[Fusionforge-commits] r10366 - branches/Branch_4_8/gforge/common/frs

Alain Peyrat aljeux at libremir.placard.fr.eu.org
Sat Aug 28 09:20:17 CEST 2010


Author: aljeux
Date: 2010-08-28 09:20:17 +0200 (Sat, 28 Aug 2010)
New Revision: 10366

Modified:
   branches/Branch_4_8/gforge/common/frs/FRSFile.class.php
Log:
Applied patch [#191] getSize() and getPostDate() methods in FRS are wrong

Modified: branches/Branch_4_8/gforge/common/frs/FRSFile.class.php
===================================================================
--- branches/Branch_4_8/gforge/common/frs/FRSFile.class.php	2010-08-28 07:19:22 UTC (rev 10365)
+++ branches/Branch_4_8/gforge/common/frs/FRSFile.class.php	2010-08-28 07:20:17 UTC (rev 10366)
@@ -254,7 +254,7 @@
 	 *  @return int	The size.
 	 */
 	function getSize() {
-		return $this->data_array['size'];
+		return $this->data_array['file_size'];
 	}
 
 	/**
@@ -312,12 +312,12 @@
 	}
 
 	/**
-	 *  getPostDate - get the post time of this file.
+	 *  getPostDate - get the post date of this file.
 	 *
 	 *  @return int	The post time in unix time.
 	 */
 	function getPostDate() {
-		return $this->data_array['post_time'];
+		return $this->data_array['post_date'];
 	}
 
 	/**
@@ -312,12 +312,12 @@
 	 *
-	 *  @return int	The post time in unix time.
+	 *  @return int	The post date in unix time.
 	 */
 	function getPostDate() {




More information about the Fusionforge-commits mailing list